/**
 * Source: https://github.com/madrobby/keymaster/blob/3b1f2afabf1569848dea8b697ac418f19b601a30/keymaster.js
 */
export var KEY_MAP = {
    "⇧": "shift",
    "⌥": "alt",
    option: "alt",
    "⌃": "control",
    ctrl: "control",
    "⌘": "meta",
    cmd: "meta",
    command: "meta",
    caps: "capslock",
    tab: "tab",
    return: "enter",
    esc: "escape",
    space: " ",
    left: "arrowleft",
    up: "arrowup",
    right: "arrowright",
    down: "arrowdown"
};
/**
 * Continue propagating the event to older listeners.
 */
export var SHOULD_PROPAGATE = true;
/**
 * Stringify a keyboard event.
 */
export function keyboardEventCombo(e) {
    var keys = new Set([String(e.key).toLocaleLowerCase()]);
    if (e.shiftKey)
        keys.add("shift");
    if (e.ctrlKey)
        keys.add("control");
    if (e.altKey)
        keys.add("alt");
    if (e.metaKey)
        keys.add("meta");
    return Array.from(keys)
        .sort()
        .join(" ");
}
/**
 * Map keys to string.
 */
export function stringifyKey() {
    var keys = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        keys[_i] = arguments[_i];
    }
    return keys
        .map(function (key) { return String(key).toLowerCase(); })
        .map(function (key) { return (KEY_MAP.hasOwnProperty(key) ? KEY_MAP[key] : key); })
        .sort()
        .join(" ");
}
/**
 * Create a listener function from shortcuts.
 */
export function createShortcuts(shortcuts, returnValue) {
    if (returnValue === void 0) { returnValue = SHOULD_PROPAGATE; }
    return function (event, combo) {
        return shortcuts[combo] ? shortcuts[combo](event, combo) : returnValue;
    };
}
/**
 * Check if a keyboard event originated from an input.
 */
export function isInputEvent(event) {
    var target = event.target;
    return (target.tagName === "INPUT" ||
        target.tagName === "SELECT" ||
        target.tagName === "TEXTAREA" ||
        target.isContentEditable);
}
/**
 * Function to wrap listener by filtering input events.
 */
export function filterInputEvent(listener) {
    return function (event, combo) {
        return isInputEvent(event) ? SHOULD_PROPAGATE : listener(event, combo);
    };
}
/**
 * Keyboard manager library for mapping key events.
 */
var Keyboard = /** @class */ (function () {
    function Keyboard() {
        this.listeners = [];
    }
    Keyboard.prototype.addListener = function (callback) {
        this.listeners.push(callback);
    };
    Keyboard.prototype.removeListener = function (callback) {
        var indexOf = this.listeners.indexOf(callback);
        if (indexOf > -1)
            this.listeners.splice(indexOf, 1);
    };
    Keyboard.prototype.getHandler = function () {
        var listener = this.getListener();
        return function (event) {
            listener(event, keyboardEventCombo(event));
        };
    };
    Keyboard.prototype.getListener = function (returnValue) {
        var _this = this;
        if (returnValue === void 0) { returnValue = SHOULD_PROPAGATE; }
        return function (event, combo) {
            var len = _this.listeners.length;
            while (len--) {
                if (_this.listeners[len](event, combo) !== SHOULD_PROPAGATE)
                    return;
            }
            return returnValue;
        };
    };
    return Keyboard;
}());
export { Keyboard };
//# sourceMappingURL=index.js.map